@@ -10,16 +10,12 @@ import sys
 import time
 import unittest
 
-import pytest
-
 import framework
 
 import thor
 from thor.events import on
 from thor.http import HttpClient
 
-thor.loop.debug = True
-
 
 class LittleServer(SocketServer.ThreadingMixIn, SocketServer.TCPServer):
     allow_reuse_address = True
@@ -163,7 +159,6 @@ Transfer-Encoding: chunked
 
         self.go([server_side], [client_side])
 
-    @pytest.mark.xfail
     def test_chunked_request(self):
         req_body = b"54321"
 
@@ -203,7 +198,6 @@ Connection: close
 12345
 """
             )
-            # TODO: check server-side recv
             conn.request.close()
 
         self.go([server_side], [client_side])
@@ -238,7 +232,6 @@ Connection: close
 
         self.go([server_side], [client_side])
 
-    @pytest.mark.xfail
     def test_1xx(self):
         req_body = b"54321"
 
@@ -369,7 +362,6 @@ Connection: close
 
         self.go([server_side], [client_side])
 
-    # FIXME: works because dns is currently blocking
     def test_conn_noname_err(self):
         client = HttpClient(loop=self.loop)
         exchange = client.exchange()
@@ -622,7 +614,6 @@ Connection: close
 
         self.go([server_side], [client_side])
 
-    @pytest.mark.xfail
     def test_http_protoname_err(self):
         def client_side(client, test_host, test_port):
             exchange = client.exchange()
@@ -693,7 +684,6 @@ Connection: close
 
         self.go([server_side], [client_side])
 
-    @pytest.mark.xfail
     def test_conn_reuse(self):
         self.conn_checked = False
 
@@ -768,7 +758,6 @@ Connection: close
         self.go([server_side], [client_side])
         self.assertTrue(self.conn_checked)
 
-    @pytest.mark.xfail
     def test_conn_succeed_then_err(self):
         self.conn_checked = False
 
@@ -836,7 +825,6 @@ Connection: close
         self.go([server_side], [client_side])
         self.assertTrue(self.conn_checked)
 
-    @pytest.mark.xfail
     def test_req_retry(self):
         def client_side(client, test_host, test_port):
             exchange = client.exchange()
@@ -1034,7 +1022,6 @@ Connection: close
         self.go([server_side], [client_side])
 
 
-# TODO:
 #    def test_req_body(self):
 #    def test_req_body_dont_retry(self):
 #    def test_req_body_close_on_err(self):
