@@ -125,12 +125,15 @@ class TestTcpClientConnect(framework.ClientServerTestCase):
         self.loop.run()
         self.assertEqual(self.connect_count, 0)
         self.assertEqual(self.error_count, 1)
-        self.assertEqual(self.last_error_type, 'socket')
-        self.assertEqual(self.last_error, errno.ETIMEDOUT,
-                         errno.errorcode.get(self.last_error, self.last_error))
+        self.assertEqual(self.last_error_type, "socket")
+        self.assertEqual(
+            self.last_error,
+            errno.ETIMEDOUT,
+            errno.errorcode.get(self.last_error, self.last_error),
+        )
         self.assertEqual(self.timeout_hit, False)
 
-# TODO:
+
 #   def test_pause(self):
 
 if __name__ == "__main__":
