@@ -44,35 +44,30 @@ from thor.http.error import (
     HttpVersionError,
     StartLineError,
 )
-from thor.http.error import HttpError  # pylint: disable=unused-import
+from thor.http.error import HttpError
 
 req_rm_hdrs = hop_by_hop_hdrs + [b"host"]
 
-# TODO: next-hop version cache for Expect/Continue, etc.
-
 
 class HttpClient:
     "An asynchronous HTTP client."
 
     def __init__(self, loop: LoopBase = None) -> None:
         self.loop = loop or thor.loop._loop
-        self.idle_timeout = 60  # type: int    # seconds
-        self.connect_attempts = 3  # type: int
-        self.connect_timeout = 3  # type: int    # seconds
-        self.read_timeout = None  # type: int    # seconds
-        self.retry_limit = 2  # type: int
-        self.retry_delay = 0.5  # type: float  # seconds
-        self.max_server_conn = 6  # type: int
-        self.check_ip = None  # type: Callable[[str], bool]
-        self.careful = True  # type: bool
-        self._outstanding = defaultdict(list)  # type: Dict[OriginType, List]
-        self._idle_conns = defaultdict(
+        self.idle_timeout: int = 60  # seconds
+        self.connect_attempts: int = 3
+        self.connect_timeout: int = 3  # seconds
+        self.read_timeout: int = None  # seconds
+        self.retry_limit: int = 2
+        self.retry_delay: float = 0.5  # seconds
+        self.max_server_conn: int = 6
+        self.check_ip: Callable[[str], bool] = None
+        self.careful: bool = True
+        self._idle_conns: Dict[OriginType, List[TcpConnection]] = defaultdict(list)
+        self.conn_counts: Dict[OriginType, int] = defaultdict(int)
+        self._req_q: Dict[OriginType, List[Tuple[Callable, Callable]]] = defaultdict(
             list
-        )  # type: Dict[OriginType, List[TcpConnection]]
-        self.conn_counts = defaultdict(int)  # type: Dict[OriginType, int]
-        self._req_q = defaultdict(
-            list
-        )  # type: Dict[OriginType, List[Tuple[Callable, Callable]]]
+        )
         self.loop.once("stop", self._close_conns)
 
     def exchange(self) -> "HttpClientExchange":
@@ -93,10 +88,10 @@ class HttpClient:
                 self._new_conn(origin, handle_connect, handle_connect_error)
                 break
             if tcp_conn.tcp_connected:
-                tcp_conn.removeListeners("data", "pause", "close")
+                tcp_conn.remove_listeners("data", "pause", "close")
                 tcp_conn.pause(True)
-                if hasattr(tcp_conn, "_idler"):
-                    tcp_conn._idler.delete()  # type: ignore
+                if hasattr(tcp_conn, "idler"):
+                    tcp_conn.idler.delete()  # type: ignore[attr-defined]
                 handle_connect(tcp_conn)
                 break
 
@@ -104,15 +99,15 @@ class HttpClient:
         "Add an idle connection back to the pool."
         tcp_conn = exchange.tcp_conn
         if tcp_conn:
-            tcp_conn.removeListeners("data", "pause", "close")
+            tcp_conn.remove_listeners("data", "pause", "close")
             exchange.tcp_conn = None
             if tcp_conn.tcp_connected:
                 origin = exchange.origin
 
                 def idle_close() -> None:
                     "Remove the connection from the pool when it closes."
-                    if hasattr(tcp_conn, "_idler"):
-                        tcp_conn._idler.delete()  # type: ignore
+                    if hasattr(tcp_conn, "idler"):
+                        tcp_conn.idler.delete()  # type: ignore[attr-defined]
                     self.dead_conn(exchange)
                     try:
                         self._idle_conns[origin].remove(tcp_conn)
@@ -126,7 +121,7 @@ class HttpClient:
                     handle_connect(tcp_conn)
                 elif self.idle_timeout > 0:
                     tcp_conn.once("close", idle_close)
-                    tcp_conn._idler = self.loop.schedule(  # type: ignore
+                    tcp_conn.idler = self.loop.schedule(  # type: ignore[attr-defined]
                         self.idle_timeout, idle_close
                     )
                     self._idle_conns[origin].append(tcp_conn)
@@ -164,13 +159,12 @@ class HttpClient:
             for conn in conn_list:
                 try:
                     conn.close()
-                except:
+                except socket.error:
                     pass
         self._idle_conns.clear()
-        # TODO: probably need to close in-progress conns too.
 
 
-class HttpConnectionInitiate:
+class HttpConnectionInitiate:  # pylint: disable=too-few-public-methods
     """
     Creates a new TCP connection to an origin.
     """
@@ -190,7 +184,7 @@ class HttpConnectionInitiate:
         self.handle_connect = handle_connect
         self.handle_error = handle_error
         self._attempts = 0
-        self._dns_results = []  # type: DnsResultList
+        self._dns_results: DnsResultList = []
         (_, host, port) = origin
         lookup(host.encode("idna"), port, socket.SOCK_STREAM, self._handle_dns)
 
@@ -212,7 +206,7 @@ class HttpConnectionInitiate:
         """
         dns_result = self._dns_results[self._attempts % len(self._dns_results)]
         (scheme, host, _) = self.origin
-        tcp_client = None  # type: Union[TcpClient, TlsClient]
+        tcp_client: Union[TcpClient, TlsClient] = None
         if scheme == "http":
             tcp_client = self.tcp_client_class(self.client.loop)
         elif scheme == "https":
@@ -252,20 +246,20 @@ class HttpClientExchange(HttpMessageHandler, EventEmitter):
         EventEmitter.__init__(self)
         self.client = client
         self.careful = client.careful
-        self.method = None  # type: bytes
-        self.uri = None  # type: bytes
-        self.req_hdrs = None  # type: RawHeaderListType
-        self.req_target = None  # type: bytes
-        self.authority = None  # type: bytes
-        self.res_version = None  # type: bytes
-        self.tcp_conn = None  # type: TcpConnection
-        self.origin = None  # type: OriginType
+        self.method: bytes = None
+        self.uri: bytes = None
+        self.req_hdrs: RawHeaderListType = None
+        self.req_target: bytes = None
+        self.authority: bytes = None
+        self.res_version: bytes = None
+        self.tcp_conn: TcpConnection = None
+        self.origin: OriginType = None
         self._conn_reusable = False
         self._req_body = False
         self._req_started = False
         self._retries = 0
-        self._read_timeout_ev = None  # type: ScheduledEvent
-        self._output_buffer = []  # type: List[bytes]
+        self._read_timeout_ev: ScheduledEvent = None
+        self._output_buffer: List[bytes] = []
 
     def __repr__(self) -> str:
         status = [self.__class__.__module__ + "." + self.__class__.__name__]
@@ -295,9 +289,6 @@ class HttpClientExchange(HttpMessageHandler, EventEmitter):
             self.origin, self._handle_connect, self._handle_connect_error
         )
 
-    # TODO: if we sent Expect: 100-continue, don't wait forever
-    # (i.e., schedule something)
-
     def _parse_uri(self, uri: bytes) -> OriginType:
         """
         Given a uri, parse out the host, port, authority and request target.
@@ -458,7 +449,6 @@ class HttpClientExchange(HttpMessageHandler, EventEmitter):
         tcp_conn.on("data", self.handle_input)
         tcp_conn.once("close", self._conn_closed)
         tcp_conn.on("pause", self._req_body_pause)
-        # FIXME: should this be done AFTER _req_start?
         self.output(b"")  # kick the output buffer
         self.tcp_conn.pause(False)
 
@@ -624,38 +614,38 @@ def test_client(
     request_uri: bytes, out: Callable, err: Callable
 ) -> None:  # pragma: no coverage
     "A simple demonstration of a client."
-    from thor.loop import stop, run, schedule
+    from thor.loop import stop, run, schedule  # pylint: disable=import-outside-toplevel
 
-    c = HttpClient()
-    c.connect_timeout = 5
-    c.careful = False
-    x = c.exchange()
+    cl = HttpClient()
+    cl.connect_timeout = 5
+    cl.careful = False
+    ex = cl.exchange()
 
-    @on(x)
+    @on(ex)
     def response_start(
         status: bytes, phrase: bytes, headers: RawHeaderListType
     ) -> None:
         "Print the response headers."
-        out(b"HTTP/%s %s %s\n" % (x.res_version, status, phrase))
+        out(b"HTTP/%s %s %s\n" % (ex.res_version, status, phrase))
         out(b"\n".join([b"%s:%s" % header for header in headers]))
         print()
         print()
 
-    @on(x)
+    @on(ex)
     def error(err_msg: HttpError) -> None:
         if err_msg:
             err(f"\033[1;31m*** ERROR:\033[0;39m {err_msg.desc} ({err_msg.detail})\n")
         if not err_msg.client_recoverable:
             stop()
 
-    x.on("response_body", out)
+    ex.on("response_body", out)
 
-    @on(x)
+    @on(ex)
     def response_done(trailers: RawHeaderListType) -> None:
         schedule(1, stop)
 
-    x.request_start(b"GET", request_uri, [])
-    x.request_done([])
+    ex.request_start(b"GET", request_uri, [])
+    ex.request_done([])
     run()
 
 
