@@ -9,21 +9,14 @@ for the parsing portions of the HTTP client and server.
 
 from collections import defaultdict
 from enum import Enum
-from typing import (
-    Callable,
-    Dict,
-    List,
-    Set,
-    Tuple,
-    Union,
-)  # pylint: disable=unused-import
+from typing import Dict, List, Set, Tuple
 
 from thor.http import error
 
-linesep = b"\r\n"
 RawHeaderListType = List[Tuple[bytes, bytes]]
 OriginType = Tuple[str, str, int]
 
+LINESEP = b"\r\n"
 NEWLINE = ord("\n")
 RETURN = ord("\r")
 
@@ -62,7 +55,7 @@ def header_names(hdr_tuples: RawHeaderListType) -> Set[bytes]:
     """
     Given a list of header tuples, return the set of the header names seen.
     """
-    return set([n.lower() for n, v in hdr_tuples])
+    return {n.lower() for n, v in hdr_tuples}
 
 
 def header_dict(
@@ -75,12 +68,12 @@ def header_dict(
     If omit is defined, each header listed (by lower-cased name) will not be
     returned in the dictionary.
     """
-    out = defaultdict(list)  # type: Dict[bytes, List[bytes]]
-    for (n, v) in hdr_tuples:
-        n = n.lower()
-        if n in (omit or []):
+    out: Dict[bytes, List[bytes]] = defaultdict(list)
+    for (name, val) in hdr_tuples:
+        name = name.lower()
+        if name in (omit or []):
             continue
-        out[n].extend([i.strip() for i in v.split(b",")])
+        out[name].extend([i.strip() for i in val.split(b",")])
     return out
 
 
@@ -94,7 +87,6 @@ def get_header(hdr_tuples: RawHeaderListType, name: bytes) -> List[bytes]:
     safe to use this on headers whose values may include a comma (e.g.,
     Set-Cookie, or any value with a quoted string).
     """
-    # TODO: support quoted strings
     return [
         v.strip()
         for v in sum(
@@ -116,17 +108,17 @@ class HttpMessageHandler:
     """
 
     careful = True  # if False, don't fail on errors, but preserve them.
-    default_state = None  # type: States  # QUIET or WAITING
+    default_state: States = None  # QUIET or WAITING
 
     def __init__(self) -> None:
         self.input_header_length = 0
         self.input_transfer_length = 0
-        self._input_buffer = []  # type: List[bytes]
+        self._input_buffer: List[bytes] = []
         self._input_state = self.default_state
-        self._input_delimit = None  # type: Delimiters
+        self._input_delimit: Delimiters = None
         self._input_body_left = 0
         self._output_state = States.WAITING
-        self._output_delimit = None  # type: Delimiters
+        self._output_delimit: Delimiters = None
 
     def __repr__(self) -> str:
         return f"input {self._input_state} output {self._output_state}"
@@ -244,11 +236,9 @@ class HttpMessageHandler:
             if len(inbytes) > 512:
                 # OK, this is absurd...
                 self.input_error(error.ChunkError(inbytes.decode("utf-8", "replace")))
-                # TODO: need testing around this; catching the right thing?
             else:
                 self._input_buffer.append(inbytes)
             return b""
-        # TODO: do we need to ignore blank lines?
         if b";" in chunk_size:  # ignore chunk extensions
             chunk_size = chunk_size.split(b";", 1)[0]
         try:
@@ -295,7 +285,7 @@ class HttpMessageHandler:
                 try:
                     trailers = self._parse_fields(trailer_block.splitlines())[0]
                 except ValueError:
-                    self._input_state = States.ERROR  # TODO: need an explicit error
+                    self._input_state = States.ERROR
                     return
                 else:
                     self.input_end(trailers)
@@ -325,12 +315,12 @@ class HttpMessageHandler:
         and without the trailing CRLFCRLF), return its header tuples.
         """
 
-        hdr_tuples = []  # type: RawHeaderListType
-        conn_tokens = []  # type: List[bytes]
-        transfer_codes = []  # type: List[bytes]
-        content_length = None  # type: int
+        hdr_tuples: RawHeaderListType = []
+        conn_tokens: List[bytes] = []
+        transfer_codes: List[bytes] = []
+        content_length: int = None
 
-        for line in header_lines:
+        for line in header_lines:  # pylint: disable=too-many-nested-blocks
             if line[:1] in [b" ", b"\t"]:  # Fold LWS
                 if hdr_tuples:
                     hdr_tuples[-1] = (
@@ -338,17 +328,16 @@ class HttpMessageHandler:
                         b"%s %s" % (hdr_tuples[-1][1], line.lstrip()),
                     )
                     continue
-                else:  # top header starts with whitespace
-                    self.input_error(
-                        error.TopLineSpaceError(line.decode("utf-8", "replace"))
-                    )
-                    if self.careful:
-                        raise ValueError
+                # top header starts with whitespace
+                self.input_error(
+                    error.TopLineSpaceError(line.decode("utf-8", "replace"))
+                )
+                if self.careful:
+                    raise ValueError
             try:
                 fn, fv = line.split(b":", 1)
             except ValueError:
-                continue  # TODO: error on unparseable field?
-            # TODO: a zero-length name isn't valid
+                continue
             if fn[-1:] in [b" ", b"\t"]:
                 self.input_error(error.HeaderSpaceError(fn.decode("utf-8", "replace")))
                 if self.careful:
@@ -362,7 +351,7 @@ class HttpMessageHandler:
                 # parse connection-related headers
                 if f_name == b"connection":
                     conn_tokens += [v.strip().lower() for v in f_val.split(b",")]
-                elif f_name == b"transfer-encoding":  # TODO: parameters? no...
+                elif f_name == b"transfer-encoding":
                     transfer_codes += [v.strip().lower() for v in f_val.split(b",")]
                 elif f_name == b"content-length":
                     if content_length is not None:
@@ -425,7 +414,7 @@ class HttpMessageHandler:
         header_lines = inbytes.splitlines()
 
         # chop off the top line
-        while True:  # TODO: limit?
+        while True:
             try:
                 top_line = header_lines.pop(0)
                 if top_line.strip() != b"":
@@ -497,7 +486,7 @@ class HttpMessageHandler:
         out = [top_line]
         out.extend([b"%s: %s" % (k.strip(), v) for k, v in hdr_tuples])
         out.extend([b"", b""])
-        self.output(linesep.join(out))
+        self.output(LINESEP.join(out))
         self._output_state = States.HEADERS_DONE
 
     def output_body(self, chunk: bytes) -> None:
@@ -509,11 +498,6 @@ class HttpMessageHandler:
         if self._output_delimit == Delimiters.CHUNKED:
             chunk = b"%s\r\n%s\r\n" % (hex(len(chunk))[2:].encode("ascii"), chunk)
         self.output(chunk)
-        # TODO: body counting
-
-    #        self._output_body_sent += len(chunk)
-    #        assert self._output_body_sent <= self._output_content_length, \
-    #            "Too many body bytes sent"
 
     def output_end(self, trailers: RawHeaderListType) -> bool:
         """
@@ -528,7 +512,7 @@ class HttpMessageHandler:
                 % b"\r\n".join([b"%s: %s" % (k.strip(), v) for k, v in trailers])
             )
         elif self._output_delimit == Delimiters.COUNTED:
-            pass  # TODO: double-check the length
+            pass
         elif self._output_delimit == Delimiters.CLOSE:
             return True
         elif self._output_delimit is None:
