@@ -4,14 +4,12 @@
 Thor HTTP Errors
 """
 
-from typing import Tuple  # pylint: disable=unused-import
+from typing import Tuple
 
 
 class HttpError(Exception):
     desc = "Unknown Error"
-    server_status = (
-        None
-    )  # type: Tuple[bytes, bytes]  # status this produces in a server
+    server_status: Tuple[bytes, bytes] = None  # status this produces in a server
     server_recoverable = False  # whether a server can recover the connection
     client_recoverable = False  # whether a client can recover the connection
 
@@ -21,7 +19,7 @@ class HttpError(Exception):
 
     def __repr__(self) -> str:
         status = [self.__class__.__module__ + "." + self.__class__.__name__]
-        return "<%s at %#x>" % (", ".join(status), id(self))
+        return f"<{', '.join(status)} at {id(self):#x}>"
 
 
 # General parsing errors
