@@ -33,8 +33,8 @@ class UdpEndpoint(EventSource):
 
     def __init__(self, loop: LoopBase = None) -> None:
         EventSource.__init__(self, loop)
-        self.host = None  # type: bytes
-        self.port = None  # type: int
+        self.host: bytes = None
+        self.port: int = None
         self._error_sent = False
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         self.sock.setblocking(False)
@@ -55,7 +55,6 @@ class UdpEndpoint(EventSource):
 
         Can raise socket.error if binding fails.
         """
-        # TODO: IPV6
         self.host = host
         self.port = port
         self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
@@ -69,9 +68,8 @@ class UdpEndpoint(EventSource):
 
     def shutdown(self) -> None:
         "Close the listening socket."
-        self.removeListeners("fd_readable")
+        self.remove_listeners("fd_readable")
         self.sock.close()
-        # TODO: emit close?
 
     def pause(self, paused: bool) -> None:
         "Control incoming datagram events."
@@ -92,8 +90,6 @@ class UdpEndpoint(EventSource):
 
     def handle_datagram(self) -> None:
         "Handle an incoming datagram, emitting the 'datagram' event."
-        # TODO: consider pre-allocating buffers.
-        # TODO: is it best to loop here?
         while True:
             try:
                 data, addr = self.sock.recvfrom(self.recv_buffer)
